value

Function value 

pub fn value(id: &str) -> f32
Gibt den aktuellen Achsenwert zurück, im Bereich 0..=1. Ohne Belegung oder vor dem ersten Messwert ist das AXIS_CENTER (0,5).

Returns the current axis value, in the range 0..=1. Without a binding, or before the first sample, this is AXIS_CENTER (0.5).