preload

Function preload 

pub fn preload(id: ContentId)
Lädt ein Asset vor (z. B. Textur oder Schrift) und hält es im Speicher, bis das Script entladen wird.

Preloads an asset (e.g. texture or font) and keeps it in memory until the script is unloaded.