#[repr(u8)]pub enum ActionStateKind {
None = 0,
JustPressed = 1,
Pressed = 2,
JustReleased = 3,
}Expand description
Art des Aktionszustands.
The state kind of an action.
Variants
None = 0
Die Aktion wird nicht ausgeführt.
The action is not being performed.
JustPressed = 1
Die Aktion wurde gerade gedrückt.
The action has just been pressed.
Pressed = 2
Die Aktion ist aktuell gedrückt.
The action is currently pressed.
JustReleased = 3
Die Aktion wurde gerade losgelassen.
The action has just been released.
Implementations
Sourceimpl ActionStateKind
impl ActionStateKind
Sourcepub fn is_just_pressed(self) -> bool
pub fn is_just_pressed(self) -> bool
Gibt true zurück, wenn die Aktion gerade gedrückt wurde.
Returns true if the action has just been pressed.
Sourcepub fn is_pressed(self) -> bool
pub fn is_pressed(self) -> bool
Gibt true zurück, wenn die Aktion aktuell gedrückt ist.
Returns true if the action is currently pressed.
Sourcepub fn is_just_released(self) -> bool
pub fn is_just_released(self) -> bool
Gibt true zurück, wenn die Aktion gerade losgelassen wurde.
Returns true if the action has just been released.
Sourcepub fn is_released(self) -> bool
pub fn is_released(self) -> bool
Gibt true zurück, wenn die Aktion aktuell nicht gedrückt ist.
Returns true if the action is currently released.