pub enum Coupling {
Front,
Rear,
}Expand description
Kupplungsrichtung zwischen Fahrzeugen in einem Zug.
Coupling direction between vehicles in a train.
Variants
Front
Kupplung zum vorderen Fahrzeug.
The coupling to the front vehicle.
Rear
Kupplung zum hinteren Fahrzeug.
The coupling to the rear vehicle.
Implementations
Sourceimpl Coupling
impl Coupling
Sourcepub fn is_open(&self, bus: &str) -> bool
pub fn is_open(&self, bus: &str) -> bool
Gibt true zurück, wenn der angegebene Bus geöffnet ist.
Returns true if the given bus is open.
Sourcepub fn is_coupled(&self) -> bool
pub fn is_coupled(&self) -> bool
Gibt true zurück, wenn an dieser Kupplung ein Fahrzeug gekoppelt ist.
Returns true if a vehicle is coupled at this coupling.