PisSpGroup

Struct PisSpGroup 

pub struct PisSpGroup {
    pub name: String,
    pub basic_pis_group: ContentId,
    pub class: String,
    pub add_lines: String,
    pub add_lines_stations: Vec<PisSpAddLines>,
    pub routes: Vec<PisSpRoute>,
}
PISS-Content-Gruppe passend zur aktiven PIS-Gruppe und einer Fahrzeugklasse.

PISS content group matching the active PIS group and a vehicle class.

Fields

name: String

Anzeigename der PISS-Gruppe.

Display name of the PISS group.

basic_pis_group: ContentId

Content-ID der zugrunde liegenden PIS-Basisgruppe.

Content id of the underlying basic PIS group.

class: String

Fahrzeugklasse, für die diese PISS-Gruppe gilt.

Vehicle class this PISS group applies to.

add_lines: String

Zusätzlicher Linienstring aus der PISS-Gruppe.

Additional line string from the PISS group.

add_lines_stations: Vec<PisSpAddLines>

Zusätzliche Linienstrings pro Station.

Additional line strings per station.

routes: Vec<PisSpRoute>

In der PISS-Gruppe definierte Routen.

Routes defined in the PISS group.

Implementations

Source

impl PisSpGroup

pub fn get_content_id(class: &str) -> Option<ContentId>

Liefert die ContentId der PISS-Gruppe, die zur aktiven PIS-Gruppe passt und die gegebene Klasse hat.

Returns the PISS group content id for the active PIS group and the given class.

pub fn get_group_strings(content_id: ContentId) -> String

Liefert die zusätzlichen Linien aus der gegebenen PISS-Gruppe.

Returns the additional line string from the given PISS group.

pub fn get_station_strings( content_id: ContentId, station_code: u32, ) -> Option<String>

Liefert die zusätzlichen Linien für eine Station aus der gegebenen PISS-Gruppe.

Returns additional line text for a station from the given PISS group.

pub fn get_route( content_id: ContentId, line: u32, code: u32, ) -> Option<PisSpRoute>

Liefert die Route mit der gegebenen Linie und dem Code aus der gegebenen PISS-Gruppe.

Returns the route for the given line and code from the given PISS group.