pub struct Animation { /* private fields */ }Expand description
Handle auf eine benannte Animation am aktuellen Objekt.
Handle to a named animation on the current object.
Implementations
Sourceimpl Animation
impl Animation
Sourcepub fn index(&self) -> usize
pub fn index(&self) -> usize
Gibt den internen Animationsindex zurück.
Returns the internal animation index.
Sourcepub fn get(name: &str) -> Result<Animation, AnimationError>
pub fn get(name: &str) -> Result<Animation, AnimationError>
Sucht eine Animation anhand ihres Namens am aktuellen Objekt.
Looks up an animation by name on the current object.
Sourcepub fn get_animation_global_acceleration_velocity(self) -> AccelerationVelocity
pub fn get_animation_global_acceleration_velocity(self) -> AccelerationVelocity
Gibt den globalen kinematischen Zustand dieser Animationseinheit zurück.
Returns the global kinematic state of this animation unit.