pub struct TrainConfigurationChanged {
pub entity_id: u64,
pub reversed_to_train: bool,
pub index_in_train: usize,
pub train_vehicle_count: usize,
}Expand description
Describes an event that is sent when the train configuration is changed. Please note: When two trains with different directions are coupled, the new direction cannot be predicted! In the vehicles of the train whose direction is inverted when coupling, “reversed_to_train” is inverted and the index order reverses.
Fields
entity_id: u64reversed_to_train: boolindex_in_train: usizetrain_vehicle_count: usizeImplementations
Sourceimpl TrainConfigurationChanged
Calculation of the vehicle count in front or behind the vehicle
relative to the vehicle.
impl TrainConfigurationChanged
Calculation of the vehicle count in front or behind the vehicle relative to the vehicle.
pub fn neighbour_vehicle_count(&self, coupling: Coupling) -> usize