pub struct BitmapFont { /* private fields */ }Expand description
Bitmap-Schrift, die zum Rendern von Text verwendet werden kann.
A bitmap font that can be used to render text.
Implementations
Sourceimpl BitmapFont
impl BitmapFont
Sourcepub fn try_load(content_id: ContentId) -> Option<Self>
pub fn try_load(content_id: ContentId) -> Option<Self>
Versucht, eine Bitmap-Schrift anhand einer Content-ID zu laden.
Gibt None zurück, solange das Asset noch im Hintergrund lädt — erneut aufrufen, bis Some zurückkommt.
Tries to load a bitmap font from a content id.
Returns None while the asset is still loading in the background; call again until Some is returned.
Sourcepub fn properties(&self) -> &BitmapFontProperties
pub fn properties(&self) -> &BitmapFontProperties
Gibt die Eigenschaften dieser Schrift zurück.
Returns the properties of this font.