MessageTarget

Enum MessageTarget 

pub enum MessageTarget {
    Myself,
    ModuleSlot(usize),
    Cockpit(u8),
    Broadcast {
        across_couplings: bool,
        include_self: bool,
    },
    AcrossCoupling {
        coupling: Coupling,
        cascade: bool,
    },
    Parent,
    // some variants omitted
}
Ziel einer Nachricht.

Represents a message target.

Variants



Myself

Das Script selbst.

The script itself.



ModuleSlot(usize)

Das Modul im Fahrzeug-Modulslot mit dem angegebenen Index (module_slot_index).

The module in the vehicle module slot with the given index (module_slot_index).



Cockpit(u8)

An alle Module im Cockpit mit dem angegebenen Index.

To all modules in the cockpit with the given index.



Broadcast

Broadcast an Scripts gemäß dem angegebenen Umfang.

Broadcast to scripts based on the specified scope.

Fields

across_couplings: bool

Ob gekuppelte Fahrzeuge einbezogen werden.

Whether to include coupled vehicles.

include_self: bool

Ob das sendende Script einbezogen wird.

Whether to include the sending script.



AcrossCoupling

Senden an eine bestimmte Kupplung.

Send to a specific coupling.

Fields

coupling: Coupling

Kupplung, an die gesendet wird.

The coupling to send to.

cascade: bool

Ob die Nachricht zur nächsten Kupplung weitergeleitet wird.

Whether to cascade the message to the next coupling.



Parent

Das übergeordnete Script.

The parent script.

Implementations

Source

impl MessageTarget

pub fn broadcast_except_self(across_couplings: bool) -> MessageTarget

Hilfsfunktion für Broadcast-Ziele ohne das eigene Script.

Helper to create a broadcast target that excludes self

pub fn broadcast_all() -> MessageTarget

Sendet an alle Scripts in der Zugbildung, einschließlich des eigenen.

Broadcasts to all scripts in the train composition, including self.