pub struct TrainConfigurationChanged {
pub entity_id: u64,
pub reversed_to_train: bool,
pub index_in_train: usize,
pub train_vehicle_count: usize,
pub train_configuration: Option<Vec<TrainVehicleConfiguration>>,
}Expand description
Ereignis bei Änderung der Zugbildung.
Hinweis: Werden Züge mit unterschiedlicher Fahrtrichtung gekuppelt, ist die neue Richtung nicht vorhersagbar.
In Fahrzeugen, deren Richtung beim Kuppeln invertiert wird, kehrt sich reversed_to_train um und die Indexreihenfolge dreht sich um.
Describes an event that is sent when the train configuration is changed.
Please note: When two trains with different directions are coupled, the new direction cannot be predicted! In the vehicles of the train whose direction is inverted when coupling, “reversed_to_train” is inverted and the index order reverses.
Fields
entity_id: u64Entity-ID des betroffenen Fahrzeugs.
Entity id of the affected vehicle.
reversed_to_train: boolOb dieses Fahrzeug relativ zum Zug gedreht ist.
Whether this vehicle is reversed relative to the train.
index_in_train: usizeNullbasierter Index dieses Fahrzeugs im Zug.
Zero-based index of this vehicle in the train.
train_vehicle_count: usizeGesamtzahl der Fahrzeuge im Zug.
Total number of vehicles in the train.
train_configuration: Option<Vec<TrainVehicleConfiguration>>Vollständige Zugbildung beim initialen Spawn; None bei späteren Updates (z. B. Script-Reload).
Full train composition at initial spawn; None for later updates (e.g. script reload).
Implementations
Sourceimpl TrainConfigurationChanged
Berechnung der Fahrzeuganzahl vor oder hinter diesem Fahrzeug.
impl TrainConfigurationChanged
Berechnung der Fahrzeuganzahl vor oder hinter diesem Fahrzeug.
Calculation of the vehicle count in front or behind the vehicle relative to the vehicle.
Sourcepub fn neighbour_vehicle_count(&self, coupling: Coupling) -> usize
pub fn neighbour_vehicle_count(&self, coupling: Coupling) -> usize
Gibt die Anzahl der Fahrzeuge in der angegebenen Richtung ab diesem Fahrzeug zurück.
Returns the number of vehicles in the given direction from this vehicle.