MessageType

Trait MessageType 

pub trait MessageType: Serialize + DeserializeOwned {
    const MESSAGE_META: MessageMeta;
}
Nachrichtentyp, der zwischen Scripts oder von der Engine gesendet werden kann.

Die Konstante MessageType::MESSAGE_META sollte global eindeutige Metadaten für den Nachrichtentyp liefern.

Represents a message type that can be sent between scripts or from the engine.

The MessageType::MESSAGE_META constant should return a globally unique message meta for the message type.

Required Associated Constants

const MESSAGE_META: MessageMeta

Metadaten für den Nachrichtentyp.

The metadata for the message type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors