PisRoute

Struct PisRoute 

pub struct PisRoute {
    pub line_code: (u32, u32),
    pub stop_codes: Vec<u32>,
    pub special_char_code: Option<u32>,
    pub routing_code: Option<u32>,
    pub text: Option<String>,
    pub termini: Vec<PisRouteTerminus>,
    pub following_line_code: Option<(u32, u32)>,
}
Datensatz für eine Route im PIS. Jeder Datensatz wird über eine Liniennummer und einen Code innerhalb der Linie identifiziert.

Fields

line_code: (u32, u32)

Liniennummer und Code innerhalb der Linie zur Zuordnung

stop_codes: Vec<u32>

Liste der Codes der Haltestellen, die auf der Route nacheinander angefahren werden, inklusive der Abfahrts- und der Endhaltestelle.

special_char_code: Option<u32>

Der Codes des Sonderzeichens, welcher automatisch ausgewählt werden soll, wenn diese Route eingestellt wird. Ob dieser Code überschrieben werden kann usw. ist abhängig vom Bordrechner.

routing_code: Option<u32>

Sind für das Balisensystem/Anforderungen/Weichen individuelle Anmelde-Codes nötig?

text: Option<String>

Zusätzliches Textfeld, welches aber aktuell keine bestimmte Bedeutung hat.

termini: Vec<PisRouteTerminus>

Im einfachsten Fall ist das Ziel (der Zielcode) einer Route einfach die letzte Haltestelle. Es kann aber sein, dass das angezeigte Ziel ab einer bestimmten Haltestelle wechseln soll, oder auch die Zielhaltestelle anders angezeigt werden soll. Für diese Fälle kann man Termini definieren.

following_line_code: Option<(u32, u32)>

Linie/Code für die automatisch zu wählende folgende Route

Implementations

Source

impl PisRoute

pub fn new( line_code: (u32, u32), stop_codes: Vec<u32>, special_char_code: Option<u32>, routing_code: Option<u32>, text: Option<String>, termini: Vec<PisRouteTerminus>, following_line_code: Option<(u32, u32)>, ) -> PisRoute

pub fn get_current_direction( &self, stop_index: usize, ) -> Option<PisRouteTerminus>