pub struct PisStation {
pub id: String,
pub code: u32,
pub interieur_display: [String; 2],
pub terminus_front_option: Option<[String; 2]>,
pub terminus_side_option: Option<[String; 2]>,
pub terminus_oneline: String,
}Expand description
Datensatz für eine Station im PIS.
PIS station record.
Fields
id: StringMit der ID wird die Station mit der Map verknüpft (auch dort gibt es eine ID für jede Station). Dies ist u. a. für die Fahrgäste und die öffentlichen KI-Fahrzeuge notwendig.
Links the station to the map (each station has an id there as well). Required e.g. for passengers and public AI vehicles.
code: u32Der Code ist die Zahl, mit der die Station innerhalb des PIS identifiziert wird. Dieser Code wird für die Anzeige auf dem PIS-Display verwendet.
Numeric code identifying the station within the PIS; used on PIS displays.
interieur_display: [String; 2]Die Strings sind die Texte, die auf den Innenanzeigen angezeigt werden. Zwei Strings gibt es z. B. für Wechselanzeigen.
Interior display texts; two strings e.g. for alternating displays.
terminus_front_option: Option<[String; 2]>Optionale zweizeilige Front-Außenanzeige.
Optional two-line front exterior destination display.
terminus_side_option: Option<[String; 2]>Optionale zweizeilige Seiten-Zielanzeige.
Optional two-line side destination display strings.
terminus_oneline: StringEinzeiliger Außenzieltext.
Single-line exterior destination text.
Implementations
Sourceimpl PisStation
impl PisStation
Sourcepub fn terminus_front(
&self,
one_to_two_line: PisStationTerminusOneLineTo,
) -> [String; 2]
pub fn terminus_front( &self, one_to_two_line: PisStationTerminusOneLineTo, ) -> [String; 2]
Liefert die (zweizeilige) Front-Außenanzeige für das Ziel.
Verfügt die Ziel-Station über keine zweizeilige Front-Außenanzeige, so wird die einzeilige
Außenanzeige um eine Leerzeile erweitert, wobei one_to_two_line die Reihenfolge dieser
Erweiterung bestimmt:
FirstLine: Die einzeilige Zeile wird in die erste Zeile und die Leerzeile in die zweite Zeile eingefügtSecondLine: Die einzeilige Zeile wird in die zweite Zeile und die Leerzeile in die erste Zeile eingefügt
Returns the (two-line) front exterior destination display.
If no two-line front display is defined, the one-line text is expanded with a blank line;
one_to_two_line controls the order:
FirstLine: one-line text on the first line, blank on the secondSecondLine: blank on the first line, one-line text on the second
Sourcepub fn terminus_side(
&self,
one_to_two_line: PisStationTerminusOneLineTo,
) -> [String; 2]
pub fn terminus_side( &self, one_to_two_line: PisStationTerminusOneLineTo, ) -> [String; 2]
Gibt die zweizeilige Seiten-Zielanzeige dieser Station zurück.
Returns the two-line side destination display for this station.
Sourcepub fn code_is_public(&self) -> bool
pub fn code_is_public(&self) -> bool
Gibt zurück, ob der Stationscode ein öffentlicher PIS-Code ist.
Returns whether the station code is a public PIS code.