pub struct Pantograph { /* private fields */ }Expand description
Handle auf einen Stromabnehmer am aktuellen Fahrzeug.
Handle to a pantograph on the current vehicle.
Implementations
Sourceimpl Pantograph
impl Pantograph
Sourcepub fn get(index: usize) -> Result<Pantograph, VehicleError>
pub fn get(index: usize) -> Result<Pantograph, VehicleError>
Gibt den Stromabnehmer am angegebenen nullbasierten Index zurück.
Returns the pantograph at the given zero-based index.
Sourcepub fn height(self) -> f32
pub fn height(self) -> f32
Gibt die Höhe des tiefsten Fahrdrads über der Stromabnehmer-Position zurück.
Returns the height of the lowest contact wire above the pantograph position.
Sourcepub fn voltage(self) -> f32
pub fn voltage(self) -> f32
Spannung der Fahrleitung über dem Stromabnehmer (normalisiert; 1.0 = Sollspannung). Das Script muss selbst prüfen, ob der Stromabnehmer die Leitung berührt.
The voltage of the contact wire above the pantograph. The value is normalized, i.e. 1.0 means that the target voltage is present. However, the script itself must check whether the pantograph is touching the contact wire.